import {
  BasicSortKeyCache,
  CacheKey,
  CacheOptions,
  EvalStateResult,
  PruneStats,
  SortKeyCacheResult,
} from "warp-contracts";
import { PgCacheOptions } from "./PgCacheOptions";
export declare class PgContractCache<V>
  implements BasicSortKeyCache<EvalStateResult<V>>
{
  private readonly cacheOptions;
  private readonly pgCacheOptions?;
  private readonly logger;
  private readonly pool;
  private client;
  constructor(cacheOptions: CacheOptions, pgCacheOptions?: PgCacheOptions);
  private sortKeyTable;
  private validityTable;
  begin(): Promise<void>;
  close(): Promise<void>;
  commit(): Promise<void>;
  delete(key: string): Promise<void>;
  dump(): Promise<any>;
  get(
    cacheKey: CacheKey
  ): Promise<SortKeyCacheResult<EvalStateResult<V>> | null>;
  getLast(key: string): Promise<SortKeyCacheResult<EvalStateResult<V>> | null>;
  getLastSortKey(): Promise<string | null>;
  getLessOrEqual(
    key: string,
    sortKey: string
  ): Promise<SortKeyCacheResult<EvalStateResult<V>> | null>;
  open(): Promise<void>;
  private connection;
  /**
     Let's assume that given contract cache contains these sortKeys: [a, b, c, d, e, f]
     Let's assume entriesStored = 2
     After pruning, the cache should be left with these keys: [e,f].
  
     const entries = await contractCache.keys({ reverse: true, limit: entriesStored }).all();
     This would return in this case entries [f, e] (notice the "reverse: true").
  
     await contractCache.clear({ lt: entries[entries.length - 1] });
     This effectively means: await contractCache.clear({ lt: e });
     -> hence the entries [a,b,c,d] are removed and left are the [e,f]
     */
  prune(entriesStored?: number): Promise<PruneStats>;
  put(stateCacheKey: CacheKey, value: EvalStateResult<V>): Promise<void>;
  private removeOldestEntries;
  /**
   * Executed in a separate pool client, so that in can be used by a separate worker.
   */
  setSignature(
    cacheKey: CacheKey,
    hash: string,
    signature: string
  ): Promise<void>;
  rollback(): Promise<void>;
  storage<S>(): S;
  drop(): Promise<void>;
}
//# sourceMappingURL=PgContractCache.d.ts.map
